@@ -8,10 +8,8 @@
 
 #include "timer.h"
 
-#include <QTimer>
-
 /* ~ Timer ~ */
-Timer::Timer(QString uuid, QObject *parent)
+Timer::Timer(const QString &uuid, QObject *parent)
     : QObject{parent}
     , m_interface{new OrgKdeKclockTimerInterface(QStringLiteral("org.kde.kclockd"), QStringLiteral("/Timers/") + uuid, QDBusConnection::sessionBus(), this)}
     , m_animationTimer{new QTimer(this)}
@@ -80,7 +78,7 @@ QString Timer::label() const
     return m_label;
 }
 
-void Timer::setLabel(QString label)
+void Timer::setLabel(const QString &label)
 {
     m_interface->setLabel(label);
 }
@@ -90,7 +88,7 @@ QString Timer::commandTimeout() const
     return m_commandTimeout;
 }
 
-void Timer::setCommandTimeout(QString commandTimeout)
+void Timer::setCommandTimeout(const QString &commandTimeout)
 {
     m_interface->setCommandTimeout(commandTimeout);
 }
