@@ -10,7 +10,6 @@
 
 #include <QLocale>
 #include <QStandardPaths>
-#include <QString>
 #include <QTimeZone>
 #include <QUrl>
 
@@ -22,6 +21,12 @@ UtilModel *UtilModel::instance()
     return singleton;
 }
 
+UtilModel::UtilModel(QObject *parent)
+    : QObject{parent}
+{
+    connect(SettingsModel::instance(), &SettingsModel::timeFormatChanged, this, &UtilModel::use24HourTimeChanged);
+}
+
 QString UtilModel::getDefaultAlarmFileLocation()
 {
     return QUrl::fromLocalFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("sounds/freedesktop/stereo/alarm-clock-elapsed.oga")))
@@ -93,12 +98,12 @@ QString UtilModel::timeToRingFormatted(const long long &timestamp)
     }
 }
 
-QString UtilModel::timeFormat()
+QString UtilModel::timeFormat() const
 {
     return use24HourTime() ? QStringLiteral("hh:mm") : QStringLiteral("hh:mm ap");
 }
 
-bool UtilModel::use24HourTime()
+bool UtilModel::use24HourTime() const
 {
     QString timeFormat = SettingsModel::instance()->timeFormat();
     if (timeFormat == QStringLiteral("SystemDefault")) {
@@ -108,7 +113,7 @@ bool UtilModel::use24HourTime()
     }
 }
 
-bool UtilModel::isLocale24HourTime()
+bool UtilModel::isLocale24HourTime() const
 {
     return QLocale::system().timeFormat(QLocale::ShortFormat).toLower().indexOf(QStringLiteral("ap")) == -1;
 }
