@@ -17,12 +17,11 @@
 #include <QDBusConnection>
 #include <QDBusMessage>
 #include <QDateTime>
-#include <QDebug>
 #include <QJsonDocument>
 #include <QJsonObject>
 
 // alarm from json (loaded from storage)
-Alarm::Alarm(QString serialized, AlarmModel *parent)
+Alarm::Alarm(const QString &serialized, AlarmModel *parent)
     : QObject{parent}
 {
     if (!serialized.isEmpty()) {
@@ -44,7 +43,7 @@ Alarm::Alarm(QString serialized, AlarmModel *parent)
     init(parent);
 }
 
-Alarm::Alarm(QString name, int hours, int minutes, int daysOfWeek, QString audioPath, int ringDuration, int snoozeDuration, AlarmModel *parent)
+Alarm::Alarm(const QString &name, int hours, int minutes, int daysOfWeek, QString audioPath, int ringDuration, int snoozeDuration, AlarmModel *parent)
     : QObject{parent}
     , m_uuid{QUuid::createUuid()}
     , m_name{name}
@@ -70,16 +69,20 @@ Alarm::~Alarm()
 void Alarm::init(AlarmModel *parent)
 {
     // setup notification
-    m_notification->setActions({i18n("Dismiss"), i18n("Snooze")});
     m_notification->setIconName(QStringLiteral("kclock"));
     m_notification->setTitle(name() == QString() ? i18n("Alarm") : name());
     m_notification->setText(QLocale::system().toString(QTime::currentTime(), QLocale::ShortFormat));
-    m_notification->setDefaultAction(i18n("View"));
     m_notification->setAutoDelete(false); // don't auto-delete when closing
 
-    connect(m_notification, &KNotification::defaultActivated, this, &Alarm::dismiss);
-    connect(m_notification, &KNotification::action1Activated, this, &Alarm::dismiss);
-    connect(m_notification, &KNotification::action2Activated, this, &Alarm::snooze);
+    auto defaultAction = m_notification->addDefaultAction(i18n("View"));
+    connect(defaultAction, &KNotificationAction::activated, this, &Alarm::dismiss);
+
+    auto dismissAction = m_notification->addAction(i18n("Dismiss"));
+    connect(dismissAction, &KNotificationAction::activated, this, &Alarm::dismiss);
+
+    auto snoozeAction = m_notification->addAction(i18n("Snooze"));
+    connect(snoozeAction, &KNotificationAction::activated, this, &Alarm::snooze);
+
     connect(m_notification, &KNotification::closed, this, &Alarm::dismiss);
 
     // setup signals
@@ -133,7 +136,7 @@ QString Alarm::name() const
     return m_name;
 }
 
-void Alarm::setName(QString name)
+void Alarm::setName(const QString &name)
 {
     if (name != m_name) {
         m_name = name;
@@ -297,6 +300,9 @@ void Alarm::ring()
     // wake up device
     Utilities::wakeupNow();
 
+    // pause playing mpris media sources
+    Utilities::pauseMprisSources();
+
     // play sound (it will loop)
     qDebug() << "Alarm sound: " << m_audioPath;
     AlarmPlayer::instance().setSource(m_audioPath);
@@ -319,6 +325,8 @@ void Alarm::dismiss()
     m_justSnoozed = false;
 
     AlarmPlayer::instance().stop();
+    Utilities::resumeMprisSources();
+
     setRinging(false);
     m_ringTimer->stop();
     m_notification->close();
@@ -331,6 +339,8 @@ void Alarm::snooze()
 {
     qDebug() << "Alarm snoozed (" << m_snoozeDuration << " minutes)";
     AlarmPlayer::instance().stop();
+    Utilities::resumeMprisSources();
+
     setRinging(false);
     m_ringTimer->stop();
     m_notification->close();
