@@ -10,9 +10,7 @@
 #include <QMediaPlayer>
 #include <QObject>
 
-#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
 #include <QAudioOutput>
-#endif
 
 class AlarmPlayer : public QObject
 {
@@ -24,7 +22,7 @@ public:
 
     int volume();
     Q_INVOKABLE void setVolume(int volume);
-    Q_INVOKABLE void setSource(QUrl path);
+    Q_INVOKABLE void setSource(const QUrl &path);
     Q_INVOKABLE void play();
     Q_INVOKABLE void stop();
 
@@ -36,17 +34,11 @@ protected:
 
 private:
     QMediaPlayer *m_player;
-#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
     QAudioOutput *m_audio;
-#endif
     quint64 startPlayingTime = 0;
 
     bool userStop = false; // indicate if user asks to stop
 
 private Q_SLOTS:
-#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
     void loopAudio(QMediaPlayer::PlaybackState state);
-#else
-    void loopAudio(QMediaPlayer::State state);
-#endif
 };
