@@ -18,7 +18,6 @@
 #include <QJsonArray>
 #include <QJsonDocument>
 #include <QJsonObject>
-#include <QObject>
 
 const QString TIMERS_CFG_GROUP = QStringLiteral("Timers"), TIMERS_CFG_KEY = QStringLiteral("timersList");
 
@@ -62,7 +61,7 @@ void TimerModel::save()
     group.sync();
 }
 
-void TimerModel::addTimer(int length, QString label, QString commandTimeout, bool running)
+void TimerModel::addTimer(int length, const QString &label, const QString &commandTimeout, bool running)
 {
     auto *timer = new Timer(length, label, commandTimeout, running);
     m_timerList.append(timer);
@@ -72,7 +71,7 @@ void TimerModel::addTimer(int length, QString label, QString commandTimeout, boo
     Q_EMIT timerAdded(timer->uuid());
 }
 
-void TimerModel::removeTimer(QString uuid)
+void TimerModel::removeTimer(const QString &uuid)
 {
     int ind = -1;
     for (int i = 0; i < m_timerList.size(); i++) {
@@ -109,7 +108,7 @@ QStringList TimerModel::timers() const
     // Filter out { } and - which are not allowed in DBus paths
     static QRegularExpression dbusfilter(QStringLiteral("[{}-]"));
 
-    for (const Timer *timer : qAsConst(m_timerList)) {
+    for (const Timer *timer : std::as_const(m_timerList)) {
         ret << timer->uuid().replace(dbusfilter, QString());
     }
     return ret;
