@@ -11,8 +11,6 @@
 #include <QDBusConnection>
 #include <QDBusInterface>
 #include <QDBusReply>
-#include <QProcess>
-#include <QTimer>
 
 KClock_1x2::KClock_1x2(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args)
     : Plasma::Applet(parent, metaData, args)
@@ -94,11 +92,16 @@ void KClock_1x2::initialTimeUpdate()
     m_timer->start(60000); // update every minute
 }
 
-QString KClock_1x2::date()
+QString KClock_1x2::date() const
 {
     return m_locale.toString(QDate::currentDate(), QStringLiteral("ddd, MMM d"));
 }
 
+QDateTime KClock_1x2::datetime() const
+{
+    return QDateTime::currentDateTime();
+}
+
 KClock_1x2::~KClock_1x2()
 {
 }
